@@ -135,8 +135,10 @@ leg_prop_line <- function(pos = "left",
   center[1] <- legend_coords$top - y_spacing -
     ifelse(title_dim$h != 0, title_dim$h + 2 * y_spacing * size, 0) -
     max_sizes[1] / 2
-  for (i in 2:n_val) {
-    center[i] <- center[i - 1] - max_sizes[i - 1] / 2 - y_spacing - max_sizes[i] / 2
+  if (n_val > 1) {
+    for (i in 2:n_val) {
+      center[i] <- center[i - 1] - max_sizes[i - 1] / 2 - y_spacing - max_sizes[i] / 2
+    }
   }
   left <- rep(legend_coords$left + x_spacing, n_box)
   right <- left + w_box
